fsleyes-widgets
===============


.. image:: https://git.fmrib.ox.ac.uk/fsl/fsleyes/widgets/badges/master/build.svg
   :target: https://git.fmrib.ox.ac.uk/fsl/fsleyes/widgets/commits/master/

.. image:: https://git.fmrib.ox.ac.uk/fsl/fsleyes/widgets/badges/master/coverage.svg
   :target: https://git.fmrib.ox.ac.uk/fsl/fsleyes/widgets/commits/master/

.. image:: https://img.shields.io/pypi/v/fsleyes-widgets.svg
   :target: https://pypi.python.org/pypi/fsleyes-widgets/



The ``fsleyes-widgets`` package contains a collection of GUI widgets and
utilities, based on `wxPython <http://www.wxpython.org>`_. These widgets are
used by `fsleyes-props <https://git.fmrib.ox.ac.uk/fsl/fsleyes/props>`_ and
`FSLeyes <https://git.fmrib.ox.ac.uk/fsl/fsleyes/fsleyes>`_,


All of the dependencies of ``fsleyes-widgets`` are listed in the
`requirements.txt <requirements.txt>`_ file.


Documentation
-------------

``fsleyes-widgets`` is documented using
`sphinx <http://http://sphinx-doc.org/>`_. You can build the API documentation
by running::

    python setup.py doc

The HTML documentation will be generated and saved in the ``doc/html/``
directory.


Contributing
------------

If you would like to contribute to ``fsleyes-widgets``, take a look at the
``fslpy`` `contributing guide
<https://git.fmrib.ox.ac.uk/fsl/fslpy/blob/master/doc/contributing.rst>`_.
